@@ -223,20 +223,38 @@ finishing test case.`;
     return core.opSync("op_get_test_origin");
   }
 
-  function dispatchTestEvent(event) {
-    return core.opSync("op_dispatch_test_event", event);
+  function reportTestPlan(plan) {
+    core.opSync("op_dispatch_test_event", {
+      plan,
+    });
+  }
+
+  function reportTestConsoleOutput(console) {
+    core.opSync("op_dispatch_test_event", {
+      output: { console },
+    });
+  }
+
+  function reportTestWait(test) {
+    core.opSync("op_dispatch_test_event", {
+      wait: test,
+    });
+  }
+
+  function reportTestResult(test, result, elapsed) {
+    core.opSync("op_dispatch_test_event", {
+      result: [test, result, elapsed],
+    });
   }
 
   async function runTests({
-    disableLog = false,
     filter = null,
     shuffle = null,
   } = {}) {
     const origin = getTestOrigin();
     const originalConsole = globalThis.console;
-    if (disableLog) {
-      globalThis.console = new Console(() => {});
-    }
+
+    globalThis.console = new Console(reportTestConsoleOutput);
 
     const only = ArrayPrototypeFilter(tests, (test) => test.only);
     const filtered = ArrayPrototypeFilter(
@@ -244,13 +262,11 @@ finishing test case.`;
       createTestFilter(filter),
     );
 
-    dispatchTestEvent({
-      plan: {
-        origin,
-        total: filtered.length,
-        filteredOut: tests.length - filtered.length,
-        usedOnly: only.length > 0,
-      },
+    reportTestPlan({
+      origin,
+      total: filtered.length,
+      filteredOut: tests.length - filtered.length,
+      usedOnly: only.length > 0,
     });
 
     if (shuffle !== null) {
@@ -278,17 +294,15 @@ finishing test case.`;
       };
       const earlier = DateNow();
 
-      dispatchTestEvent({ wait: description });
+      reportTestWait(description);
 
       const result = await runTest(test);
       const elapsed = DateNow() - earlier;
 
-      dispatchTestEvent({ result: [description, result, elapsed] });
+      reportTestResult(description, result, elapsed);
     }
 
-    if (disableLog) {
-      globalThis.console = originalConsole;
-    }
+    globalThis.console = originalConsole;
   }
 
   window.__bootstrap.internals = {
