@@ -63,6 +63,10 @@ pub struct RunArgs {
   cwd: Option<String>,
   clear_env: bool,
   env: Vec<(String, String)>,
+  #[cfg(unix)]
+  gid: Option<u32>,
+  #[cfg(unix)]
+  uid: Option<u32>,
   stdin: String,
   stdout: String,
   stderr: String,
@@ -123,6 +127,24 @@ fn op_run(
     c.env(key, value);
   }
 
+  #[cfg(unix)]
+  if let Some(gid) = run_args.gid {
+    super::check_unstable(state, "Deno.run.gid");
+    c.gid(gid);
+  }
+  #[cfg(unix)]
+  if let Some(uid) = run_args.uid {
+    super::check_unstable(state, "Deno.run.uid");
+    c.uid(uid);
+  }
+  #[cfg(unix)]
+  unsafe {
+    c.pre_exec(|| {
+      libc::setgroups(0, std::ptr::null());
+      Ok(())
+    });
+  }
+
   // TODO: make this work with other resources, eg. sockets
   if !run_args.stdin.is_empty() {
     c.stdin(subprocess_stdio_map(run_args.stdin.as_ref())?);
@@ -198,7 +220,7 @@ fn op_run(
 
 #[derive(Serialize)]
 #[serde(rename_all = "camelCase")]
-struct RunStatus {
+struct ProcessStatus {
   got_signal: bool,
   exit_code: i32,
   exit_signal: i32,
@@ -208,7 +230,7 @@ async fn op_run_status(
   state: Rc<RefCell<OpState>>,
   rid: ResourceId,
   _: (),
-) -> Result<RunStatus, AnyError> {
+) -> Result<ProcessStatus, AnyError> {
   let resource = state
     .borrow_mut()
     .resource_table
@@ -227,7 +249,7 @@ async fn op_run_status(
     .expect("Should have either an exit code or a signal.");
   let got_signal = signal.is_some();
 
-  Ok(RunStatus {
+  Ok(ProcessStatus {
     got_signal,
     exit_code: code.unwrap_or(-1),
     exit_signal: signal.unwrap_or(-1),
@@ -288,13 +310,14 @@ pub fn kill(pid: i32, signal: i32) -> Result<(), AnyError> {
 #[derive(Deserialize)]
 struct KillArgs {
   pid: i32,
-  signo: i32,
+  signo: String,
 }
 
 fn op_kill(state: &mut OpState, args: KillArgs, _: ()) -> Result<(), AnyError> {
   super::check_unstable(state, "Deno.kill");
   state.borrow_mut::<Permissions>().run.check_all()?;
 
-  kill(args.pid, args.signo)?;
+  let signo = super::signal::signal_str_to_int(&args.signo)?;
+  kill(args.pid, signo)?;
   Ok(())
 }
