@@ -320,6 +320,7 @@ impl WebWorker {
         None,
         None,
         options.unsafely_ignore_certificate_errors.clone(),
+        None,
       ),
       deno_websocket::init::<Permissions>(
         options.user_agent.clone(),
@@ -388,14 +389,7 @@ impl WebWorker {
     });
 
     if let Some(server) = options.maybe_inspector_server.clone() {
-      let inspector = js_runtime.inspector();
-      let session_sender = inspector.get_session_sender();
-      let deregister_rx = inspector.add_deregister_handler();
-      server.register_inspector(
-        session_sender,
-        deregister_rx,
-        main_module.to_string(),
-      );
+      server.register_inspector(main_module.to_string(), &mut js_runtime);
     }
 
     let (internal_handle, external_handle) = {
